..
   Copyright (C) 2023 Roberto Rossini <roberros@uio.no>
   SPDX-License-Identifier: MIT

Introduction
============

hictkpy provides Python bindings to `hictk <https://github/paulsengroup/hictk>`_, a blazing fast toolkit to work with .hic and .cool files.

.. only:: not latex

   Documentation formats
   ---------------------

   You are reading the HTML version of the documentation. An alternative `PDF
   version <https://hictkpy.readthedocs.io/_/downloads/en/latest/pdf/>`__ is
   also available.

   Installation
   ------------

.. only:: latex

   .. rubric:: Installation

Python bindings for hictk can be installed using pip or conda. See :doc:`here <./installation>` for more details.

.. only:: not latex

   How to cite this project?
   -------------------------

.. only:: latex

   .. rubric:: How to cite this project?

Please use the following BibTeX template to cite hictkpy in scientific
discourse:

.. code-block:: bibtex

    @misc{hictk,
       author = {Roberto Rossini},
       year = {2023},
       note = {https://github.com/paulsengroup/hictk},
       title = {hictk: blazing fast toolkit to work with .hic and .cool files}
    }


.. only:: not latex

   Table of contents
   -----------------

.. toctree::
   :maxdepth: 1

   installation
   quickstart

.. toctree::
   :caption: API Reference
   :maxdepth: 1

   hictkpy
